@@ -99,6 +99,12 @@ class AsyncWeb3:
     async def send_raw_transaction(self, txdata):
         return await self._do_request(RPCMethod.eth_sendRawTransaction, [txdata])
 
+    async def get_transaction_receipt(self, txhash):
+        return await self._do_request(RPCMethod.eth_getTransactionReceipt, [txhash])
+
+    async def get_transaction(self, txhash):
+        return await self._do_request(RPCMethod.eth_getTransactionByHash, [txhash])
+
     async def subscribe_block(self) -> Subscription:
         return await self._do_subscribe("newHeads")
 
