@@ -11,6 +11,8 @@ class RPCMethod:
     eth_getBlockByHash = "eth_getBlockByHash"
     eth_getBlockByNumber = "eth_getBlockByNumber"
     eth_getTransactionCount = "eth_getTransactionCount"
+    eth_getTransactionReceipt = "eth_getTransactionReceipt"
+    eth_getTransactionByHash = "eth_getTransactionByHash"
 
     eth_call = "eth_call"
     eth_sendRawTransaction = "eth_sendRawTransaction"
